@@ -22,7 +22,7 @@ class MetaInfo:
             read_only(bool): set the value data to read_only
         """
         self.read_only = read_only
-        self._callback = list()
+        self._callback = []
 
     def __call__(self, value: Any):
         """ call all callback functions on given value
@@ -196,8 +196,8 @@ class Blackboard:
             return list(self._meta_info.keys())
         return self._meta_info.keys()
 
-    def register_callback(self, key: str,
-                          callback: Callable[[Any], Any]) -> int:
+    def register_callback(self, key: str, callback: Callable[[Any],
+                                                             Any]) -> int:
         """ register a callback on the memory values
 
         Arguments:
@@ -296,7 +296,7 @@ class Blackboard:
         for key, meta_info in self._meta_info.items():
             read_only = meta_info.read_only
             saved_meta_info[key] = read_only
-        with open(file_path, 'w') as outfile:
+        with open(file_path, 'w', encoding="utf8") as outfile:
             json.dump(saved_meta_info, outfile)
 
     def _load_meta_info(self, file_path: str):
@@ -305,7 +305,7 @@ class Blackboard:
         Arguments:
             file_path: path to meta file
         """
-        with open(file_path, 'r') as infile:
+        with open(file_path, 'r', encoding="utf8") as infile:
             saved_meta_info = json.load(infile)
         if self._meta_info:
             self._meta_info.clear()
