@@ -1,4 +1,4 @@
-""" working with file formates """
+"""working with file formates"""
 from typing import Dict, Any
 from datetime import datetime
 from abc import ABC, abstractmethod
@@ -17,13 +17,32 @@ except:
     print("cannot use magic")
 
 
+# pylint: disable=C0201
+def fingerprint(file_: Path, method: str = "sha1"):
+    """ build file fingerprint """
+    method = method.lower()
+    assert (method in DIGITS.keys()), f"cannot find the hashmethod. \
+                please select on of {DIGITS.keys()}"
+
+    assert (file_.exists()), f"{file_.absolute()} is not a file!"
+
+    # retrun hashed file
+    return DIGITS[method](file_)
+
+
+def compair(file_, file_2, method="sha1"):
+    """ compair two files utilizing the fingerprint """
+    return str(fingerprint(file_, method=method).hexdigest()) == \
+           str(fingerprint(file_2, method=method).hexdigest())
+
 
 # pylint: disable=W0311
 class FileFormat(ABC):
     """ base class. so each object implements the same functions """
-    def __init__(self, path: str,
-                kwargs:Dict = None,
-                data:Any = None) -> None:
+    def __init__(self,
+                 path: str,
+                 kwargs: Dict = None,
+                 data: Any = None) -> None:
         """ Set the informations """
         self._filepath = Path(path).absolute()
 
@@ -44,16 +63,17 @@ class FileFormat(ABC):
         """ read information from file into data buffer """
 
     @abstractmethod
-    def write(self, sink:str, create: bool = True) -> None:
+    def write(self, sink: str, create: bool = True) -> None:
         """ write buffer into file"""
 
+    # pylint: disable=W0238
     def __exists(self, create: bool = False) -> bool:
         """ does the file exists? if not exists, we can create the file """
         if self._filepath.exists():
             return True
 
         if create:
-             self._filepath.touch("755", exist_ok=True)
+            self._filepath.touch("755", exist_ok=True)
         else:
             raise FileNotFoundError(f"cannot find {self._filepath}")
 
@@ -102,21 +122,13 @@ class FileFormat(ABC):
             meta["mime"] = "null"
             meta["magic-type"] = "null"
 
-
         return meta
 
-    def fingerprint(self, method:str="sha1"):
+    def fprint(self, method: str = "sha1"):
         """ build file fingerprint """
-        method = method.lower()
-        assert (method in DIGITS.keys()
-            ), f"cannot find the hashmethod. \
-                please select on of {DIGITS.keys()}"
-        assert (self.__exists(create=False)), f"{self._filepath} is not a file!"
+        return fingerprint(self._filepath, method=method)
 
-        # retrun hashed file
-        return DIGITS[method](self._filepath)
-
-    def compair(self, fileformat, method="sha1"):
+    def __eq__(self, fileformat, method="sha1"):
         """ compair two files utilizing the fingerprint """
-        return str(self.fingerprint(method=method).hexdigest()) == \
-                    str(fileformat.fingerprint(method=method).hexdigest())
+        return compair(self.fprint(method=method),
+                       fileformat.fprint(method=method))
