@@ -5,9 +5,6 @@ __email__ = "anton.feldmann@gmail.com"
 __author__ = "anton feldmann"
 
 from apu.mp.parallel_for import parallel_for
-from apu.mp.thread_funcrun import (thread_funcrun,
-                                 thread_n_funcrun)
+from apu.mp.thread_funcrun import (thread_funcrun, thread_n_funcrun)
 
-__all__ = ['parallel_for',
-           'thread_funcrun',
-           'thread_n_funcrun']
+__all__ = ['parallel_for', 'thread_funcrun', 'thread_n_funcrun']
